
class Keys(object):
    # angle = 'Angle'
    # offset = 'Offset'
    # factor = 'Factor'
    # Aspect = 'Aspect'
    # ImagePos = 'ImagePos'

    Temporary = 'Temporary'
    Path = 'Path'

    width = 'Width'
    height = 'Height'

    x = 'X'
    y = 'Y'

    # crop = 'crop'
    # zoom = 'zoom'
    # rotate = 'rotate'
    # resize = 'resize'
    # placement = 'placement'
    # scaled_size = 'scaled_size'

    # TopLeft = 'TopLeft'
    # TopRight = 'TopRight'
    # BottomLeft = 'BottomLeft'
    # BottomRight = 'BottomRight'
    #
    # IsCustom = 'IsCustom'
    #
    # default = None
